@@ -228,9 +228,14 @@ sub on_deactivate {
     #  Catalyst stash     
     $self->copy_stash if $c->config->{wizard}{autostash};
 
+    warn "Deactivating with ".$self->parentid if $DEBUG;
+    if ( $DEBUG && $self->parentid ) {
+	local $self->{c};
+	warn Dumper($self);
+    }
     #    ( sub wizard)     
     #     
-    if ($self->parentid && $self->{step} == scalar @{$self->{steps}} ) {
+    if ($self->parentid && $self->{step} >= scalar @{$self->{steps}} ) {
         my $p_wizard = $c->wizards->{$self->parentid};
 
         foreach my $field (qw(data stash params)) {
@@ -284,6 +289,7 @@ sub _construct_sub {
     #    wizard(-sub ... )    --
     my $sub = do {
         local $self->c->req->params->{wid};
+	warn "Creating sub wizard..."    if ($DEBUG);
         $self->c->start_wizard(@options);
     };
 
@@ -300,7 +306,7 @@ sub _construct_sub {
     $self->{added}{$mark} = 1;
 
     #    
-    $sub->{$_} = \%{ %{$self->{$_}} } foreach qw(data stash params added);
+    $sub->{$_} = { %{ $self->{$_} } } foreach qw(data stash params added);
 
     if ($DEBUG) { 
         local $sub->{c};
@@ -626,6 +632,8 @@ sub next_or_default {
 
     return wantarray ? @next : $next[0] if @next;
 
+    warn "$self->{id} and parent is: ".$self->parentid;
+
     #   wizard     
     # (   :-( )
     $self->{created} = 1 unless $self->parentid;
